@@ -92,6 +92,9 @@ nitpicky = True
 # NOTE: consider having a separate ignore file
 # Ref: https://stackoverflow.com/a/30624034/595220
 nitpick_ignore = [
+    ('py:class', 'cheroot.connections.ConnectionManager'),
+    ('py:meth', 'cheroot.connections.ConnectionManager.get_conn'),
+
     ('py:const', 'socket.SO_PEERCRED'),
     ('py:class', '_pyio.BufferedWriter'),
     ('py:class', '_pyio.BufferedReader'),
@@ -106,3 +109,6 @@ sphinx_tabs_valid_builders = ['linkcheck']  # prevent linkcheck warning
 # Ref: https://github.com/python-attrs/attrs/pull/571/files\
 #      #diff-85987f48f1258d9ee486e3191495582dR82
 default_role = 'any'
+
+
+html_theme = 'alabaster'
